/*
   Copyright (c) 2014 by Plexim GmbH
   All rights reserved.

   A free license is granted to anyone to use this software for any legal
   non safety-critical purpose, including commercial applications, provided
   that:
   1) IT IS NOT USED TO DIRECTLY OR INDIRECTLY COMPETE WITH PLEXIM, and
   2) THIS COPYRIGHT NOTICE IS PRESERVED in its entirety.

   THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS
   OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
   FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
   AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
   LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
   OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
   SOFTWARE.
 */

#include "includes.h"

#define ADC_usDELAY 10000L
extern void DSP28x_usDelay(unsigned long Count);

/*
 * Configure ADC
 */
void initADC()
{
   EALLOW;

   SysCtrlRegs.PCLKCR0.bit.ADCENCLK = 1;  // Enable ADC peripheral clock
   (*Device_cal )();                      // Auto-calibrate from TI OTP
   EDIS;

   DELAY_US(ADC_usDELAY);
   AdcRegs.ADCCTL1.all = ADC_RESET_FLAG;
   asm(" NOP ");
   asm(" NOP ");

   // Power up band gap
   AdcRegs.ADCCTL1.bit.ADCBGPWD = 1;

   // Delay before powering up rest of ADC
   DELAY_US(ADC_usDELAY);

   AdcRegs.ADCCTL1.bit.ADCREFSEL = 0;
   // Power up reference and rest of ADC
   AdcRegs.ADCCTL1.bit.ADCREFPWD = 1;
   AdcRegs.ADCCTL1.bit.ADCPWDN = 1;
   AdcRegs.ADCCTL1.bit.ADCENABLE = 1;

   asm(" RPT#100 || NOP");

   AdcRegs.ADCCTL1.bit.INTPULSEPOS = 1;
   AdcRegs.ADCCTL1.bit.TEMPCONV = 0;

   DELAY_US(ADC_usDELAY);

   //CHANNEL SELECTION and SOC Configuration
   AdcRegs.ADCSOC0CTL.bit.CHSEL = 1;   // ChSelect: ADC A1 -> Phase U Current*/
   AdcRegs.ADCSOC0CTL.bit.TRIGSEL = 5; // Set SOC0 start trigger on EPWM1A, due to round-robin SOC0 converts first then SOC1*/
   AdcRegs.ADCSOC0CTL.bit.ACQPS = 6;   // Set SOC0 S/H Window to 7 ADC Clock Cycles, (6 ACQPS plus 1)*/

   AdcRegs.ADCSOC1CTL.bit.CHSEL = 9;   // ChSelect: ADC B1-> Phase V Current
   AdcRegs.ADCSOC1CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC1CTL.bit.ACQPS = 6;

   AdcRegs.ADCSOC2CTL.bit.CHSEL = 3;   // ChSelect: ADC A3-> Phase W Current
   AdcRegs.ADCSOC2CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC2CTL.bit.ACQPS = 6;

   AdcRegs.ADCSOC3CTL.bit.CHSEL = 15;  // ChSelect: ADC B7-> V Phase A
   AdcRegs.ADCSOC3CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC3CTL.bit.ACQPS = 6;

   AdcRegs.ADCSOC4CTL.bit.CHSEL = 7;   //ChSelect: ADC A7-> V Phase B
   AdcRegs.ADCSOC4CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC4CTL.bit.ACQPS = 6;

   AdcRegs.ADCSOC5CTL.bit.CHSEL = 12;  // ChSelect: ADC B4-> V Phase C
   AdcRegs.ADCSOC5CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC5CTL.bit.ACQPS = 6;

   AdcRegs.ADCSOC6CTL.bit.CHSEL = 2;   // ChSelect: ADC A2-> Low Side DC Bus Return Cur.
   AdcRegs.ADCSOC6CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC6CTL.bit.ACQPS = 6;

   AdcRegs.ADCSOC7CTL.bit.CHSEL = 10;  // ChSelect: ADC B2-> DC Bus Voltage
   AdcRegs.ADCSOC7CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC7CTL.bit.ACQPS = 6;

   AdcRegs.ADCSOC8CTL.bit.CHSEL = 8;   // ChSelect: ADC B0-> Trim
   AdcRegs.ADCSOC8CTL.bit.TRIGSEL = 5;
   AdcRegs.ADCSOC8CTL.bit.ACQPS = 6;

   EDIS;
}
