/*
 Copyright (c) 2014 by Plexim GmbH
 All rights reserved.

 NOTICE: This software embodies unpublished proprietary
 and trade secret information of Plexim GmbH.  Any copying,
 disclosure or transmission not expressly authorized by
 the owner is expressly prohibited. Plexim GmbH retains exclusive
 ownership of all intellectual property rights in this software,
 including all copyright, trade secret and patent rights.
 */

/**
 * @file pidq.h
 * @brief Synchronous frame PI-Regulator with decoupling and anti-windup.
 */

#ifndef PIDQ_H_
#define PIDQ_H_

#include "plx_types.h"

#ifdef __cplusplus
extern "C" {
#endif

// fixed-point references
#define PLX_PIDQ_Q_WE 10
#define PLX_PIDQ_R_WE 10
#define PLX_PIDQ_Q_KP 10
#define PLX_PIDQ_R_KP 1024
#define PLX_PIDQ_Q_KI 14
#define PLX_PIDQ_R_KI 16384
#define PLX_PIDQ_Q_ONE 14
#define PLX_PIDQ_R_ONE 16384

typedef struct PLX_PIDQ_OBJ
{
	int16_t data[38];
} PLX_PIDQ_Obj_t;

typedef struct PLX_PIDQ_Obj_t *PLX_PIDQ_Handle_t;

extern PLX_PIDQ_Handle_t PLX_PIDQ_init(void *aMemory, const size_t aNumBytes);

extern void PLX_PIDQ_configure(PLX_PIDQ_Handle_t aPidqHandle,
		int16_t aPuWrefTsScaling,
		int16_t aKpD, int16_t aKiD,
		int16_t aKpQ, int16_t aKiQ);

extern void PLX_PIDQ_reset(PLX_PIDQ_Handle_t aPidqHandle);

extern void PLX_PIDQ_updateCrossCouplingGains(PLX_PIDQ_Handle_t aPidqHandle,  int16_t aWe);

// disable interrupts when calling this function
extern void PLX_PIDQ_applyCrossCouplingGains(PLX_PIDQ_Handle_t aPidqHandle);

extern void PLX_PIDQ_calculateOutput(PLX_PIDQ_Handle_t aPidqHandle,
		int16_t aErrorD, int16_t aErrorQ, int16_t *aOutD, int16_t *aOutQ);

extern void PLX_PIDQ_updateIntegrator(PLX_PIDQ_Handle_t aPidqHandle, int16_t aOutDLimited, int16_t aOutQLimited);

#ifdef __cplusplus
}
#endif // extern "C"

#endif /* PIDQ_H_ */
