%--- Source
Vs = 200; % input voltage
Rs = 0.02; % input impedance

%--- Converter
C.Clo = 360e-6; % input capacitor
C.Chi = 1000e-6; % output capacitor

C.Vlo0 = Vs; % initial condition for input cap
C.Vhi0 = 400.0; % initial condition for output cap

C.Ioutmax = 100; % max discharge current
C.Iinmax = -C.Ioutmax; % max regen current

C.L = 700e-6; % inductance of output choke
C.Rl = 0.01; % ESR of output choke

C.fs = 10e3; % switching frequency

%% current controller
C.f_Iloop = C.fs; % sampling frequency 
C.Tp_Iloop = (1.0/C.fs)/2; % equivalent delay

C.Ti_Iloop = 2/C.Rl*C.Tp_Iloop;
C.Tn_Iloop = C.L/C.Rl;

C.Ra = C.Tn_Iloop/C.Ti_Iloop; % Kp
C.Rsa = 1/C.Ti_Iloop; % Ki

%% voltage controller
C.f_Vloop = C.fs/10; % sampling frequency 
C.Tp_Vloop = (1.0/C.f_Vloop)/2; % equivalent delay

C.Ti_Vloop = 8/C.Chi*C.Tp_Vloop*C.Tp_Vloop;
C.Tn_Vloop = 4*C.Tp_Vloop;

C.Ga = C.Tn_Vloop/C.Ti_Vloop; % Kp
C.Gsa = 1/C.Ti_Vloop; % Ki

%--- Electric drive 
P.J = 0.001; % motor inertia
D.Cbus = 2.5e-3; % bus capacitance
D.Rbus = 0.001; % bus cap ESR
D.Vbat = C.Vhi0;

%% motor Parameters (low-inertia servo BSM90N-175A)
M.Rs = 1.24/2;
M.Ld = 0.00414; 
M.Lq = 0.00414;
M.Lss = (M.Ld + M.Lq)/50;
M.P = 2*4;
M.Psir  = 0.101;
M.Id0 = 0;
M.Iq0 = 0;
M.thm0 = 0;
M.is0 = [M.Id0 M.Iq0];

%% current controller
D.fpwm = 10000;
D.fs = D.fpwm;
D.Tpwm = 1/D.fpwm;
D.Tdt = 0.00*D.Tpwm; % deadtime
D.Ts = 1/D.fs;

D.Tcs = 1/(2*pi*100000); % current sensor bandwidth

Ri.Ts = D.Ts;
Ri.Tcalc = 0.5/D.fs;
Ri.Ta = 0.5/D.fpwm;
Ri.Tsh = 0.5/D.fs;
Ri.Tp = Ri.Tcalc + Ri.Ta + Ri.Tsh + D.Tcs;

Ri.Ra = 0.0;
Ri.R = M.Rs + Ri.Ra;

Ri.Tii = 2/Ri.R*Ri.Tp;
Ri.Tni_D = M.Ld/Ri.R;
Ri.Tni_Q = M.Lq/Ri.R;

Ri.Ki = 1/Ri.Tii;
Ri.Kp_D = Ri.Tni_D/Ri.Tii;
Ri.Kp_Q = Ri.Tni_Q/Ri.Tii;

Ri.Ra = Ri.Ra;
Ri.Vd0 = M.Rs * M.Iq0;
Ri.Vq0 = M.Rs * M.Id0 + 0*M.P/2*(M.Psir+M.Ld*M.Id0);
Ri.V0 = [Ri.Vd0 Ri.Vq0];
Ri.Tcalc = Ri.Tcalc;
Ri.Ts = Ri.Ts;
Ri.Tn_D = Ri.Tni_D;
Ri.Tn_Q = Ri.Tni_Q;
Ri.Ti = Ri.Tii;
Ri.Kp = [Ri.Kp_D Ri.Kp_Q];
Ri.Ki = [Ri.Ki Ri.Ki];

%% speed controller
Rw.Ts = 1/1000; % sample time
Rw.Tcalc = Rw.Ts/10; % calculation delay
Rw.Tp = Rw.Ts/2 + Rw.Tcalc; % equivalent delay

Rw.Ti = 8/P.J*Rw.Tp*Rw.Tp;
Rw.Tn = 4*Rw.Tp;

Rw.Kp = Rw.Tn/Rw.Ti;
Rw.Ki = 1/Rw.Ti;
